pygeodesy.ecef.Ecef9Tuple

Package pygeodesy :: Module ecef :: Class Ecef9Tuple |
[frames] | no frames]

# Class Ecef9Tuple

           object --+
                    |
                tuple --+
                        |
           object --+   |
                    |   |
         named._Named --+
                        |
        named._NamedTuple --+
                            |
           object --+       |
                    |       |
         named._Named --+   |
                        |   |
    ecefLocals._EcefLocal --+
                            |
                           Ecef9Tuple

9-Tuple `(x, y, z, lat, lon, height, C, M, datum)` with geocentric `x`, `y` and `z` plus geodetic `lat`, `lon` and `height`, case `C` and optionally, rotation matrix `M` (EcefMatrix) and `datum`, with `lat` and `lon` in `degrees` and `x`, `y`, `z` and `height` in `meter`, conventionally. Case `C=1` means normal, `C=2` near polar and `C=3` equatorial latitude and `C=4` height exceeds `heightMax`.

Instance Methods
convertDatum(self, datum2) DEPRECATED, use method toDatum. |
toCartesian(self, Cartesian=None, **Cartesian_kwds) Return the geocentric `(x, y, z)` coordinates as an ellipsoidal or spherical `Cartesian`. |
toDatum(self, datum2, **name) Convert this `Ecef9Tuple` to an other datum. |
toLatLon(self, LatLon=None, **LatLon_kwds) Return the geodetic `(lat, lon, height[, datum])` coordinates. |
toVector(self, Vector=None, **Vector_kwds) Return these geocentric `(x, y, z)` coordinates as vector. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| ellipsoid Get the ellipsoid (Ellipsoid).
| lam Get the longitude in `radians` (`float`).
| lamVermeille Get the longitude in `radians` [-PI*3/2..+PI*3/2] after Vermeille (2004), page 95.
| latlon Get the lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`).
| latlonheight Get the lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`).
| latlonheightdatum Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`).
| latlonVermeille Get the latitude and Vermeille longitude in `degrees [-225..+225]` (LatLon2Tuple`(lat, lon)`).
| lonVermeille Get the longitude in `degrees [-225..+225]` after Vermeille 2004, page 95.
| Mx Compute rotation matrix (EcefMatrix), seperate from `M`.
| phi Get the latitude in `radians` (`float`).
| philam Get the lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`).
| philamheight Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`).
| philamheightdatum Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`).
| philamVermeille Get the latitude and Vermeille longitude in `radians [-PI*3/2..+PI*3/2]` (PhiLam2Tuple`(phi, lam)`).
| phiVermeille Get the latitude in `radians` (`float`).
| xyz Get the geocentric `(x, y, z)` coordinates (Vector3Tuple`(x, y, z)`).
| xyzh Get the geocentric `(x, y, z)` coordinates and `height` (Vector4Tuple`(x, y, z, h)`)
Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### convertDatum (self, datum2) |
DEPRECATED, use method toDatum. Decorators: `@deprecated_method`

### toCartesian (self, Cartesian=None, **Cartesian_kwds) |
Return the geocentric `(x, y, z)` coordinates as an ellipsoidal or spherical `Cartesian`. Arguments: `Cartesian` - Optional class to return `(x, y, z)` (ellipsoidalKarney.Cartesian, ellipsoidalNvector.Cartesian, ellipsoidalVincenty.Cartesian, sphericalNvector.Cartesian or sphericalTrigonometry.Cartesian) or `None`. `Cartesian_kwds` - Optionally, additional `Cartesian` keyword arguments, ignored if `Cartesian is None`. Returns: A `Cartesian` instance or a Vector4Tuple`(x, y, z, h)` if `Cartesian is None`. Raises: `TypeError` - Invalid `Cartesian` or `Cartesian_kwds` item.

### toDatum (self, datum2, **name) |
Convert this `Ecef9Tuple` to an other datum. Arguments: `datum2` - Datum to convert to (Datum). `name` - Optional `name=NN` (`str`). Returns: The converted 9-Tuple (`Ecef9Tuple`). Raises: `TypeError` - The `datum2` is not a Datum.

### toLatLon (self, LatLon=None, **LatLon_kwds) |
Return the geodetic `(lat, lon, height[, datum])` coordinates. Arguments: `LatLon` - Optional class to return `(lat, lon, height[, datum])` or `None`. `LatLon_kwds` - Optional `height`, `datum` and other `LatLon` keyword arguments. Returns: A `LatLon` instance or if `LatLon is None`, a LatLon4Tuple`(lat, lon, height, datum)` or LatLon3Tuple`(lat, lon, height)` if `datum` is specified or not. Raises: `TypeError` - Invalid `LatLon` or `LatLon_kwds` item.

### toVector (self, Vector=None, **Vector_kwds) |
Return these geocentric `(x, y, z)` coordinates as vector. Arguments: `Vector` - Optional vector class to return `(x, y, z)` or `None`. `Vector_kwds` - Optional, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: A `Vector` instance or a Vector3Tuple`(x, y, z)` if `Vector is None`. Raises: `TypeError` - Invalid `Vector` or `Vector_kwds` item. See Also: Propertes `xyz` and `xyzh`

Property Details

### ellipsoid Get the ellipsoid (Ellipsoid). Get method: ellipsoid(self) - Get the ellipsoid (Ellipsoid). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lam Get the longitude in `radians` (`float`). Get method: lam(self) - Get the longitude in `radians` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lamVermeille Get the longitude in `radians` [-PI*3/2..+PI*3/2] after Vermeille (2004), page 95. Get method: lamVermeille(self) - Get the longitude in `radians` [-PI*3/2..+PI*3/2] after Vermeille (2004), page 95. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Karney, Vermeille 2011, pp 112-113, 116 and Featherstone, et.al., page 7.

### latlon Get the lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Get method: latlon(self) - Get the lat-, longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheight Get the lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`). Get method: latlonheight(self) - Get the lat-, longitude in `degrees` and height (LatLon3Tuple`(lat, lon, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheightdatum Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Get method: latlonheightdatum(self) - Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonVermeille Get the latitude and Vermeille longitude in `degrees [-225..+225]` (LatLon2Tuple`(lat, lon)`). Get method: latlonVermeille(self) - Get the latitude and Vermeille longitude in `degrees [-225..+225]` (LatLon2Tuple`(lat, lon)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property `lonVermeille`.

### lonVermeille Get the longitude in `degrees [-225..+225]` after Vermeille 2004, page 95. Get method: lonVermeille(self) - Get the longitude in `degrees [-225..+225]` after Vermeille 2004, page 95. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property `lamVermeille`.

### Mx Compute rotation matrix (EcefMatrix), seperate from `M`. Get method: Mx(self) - Compute rotation matrix (EcefMatrix), seperate from `M`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### phi Get the latitude in `radians` (`float`). Get method: phi(self) - Get the latitude in `radians` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philam Get the lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Get method: philam(self) - Get the lat-, longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheight Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Get method: philamheight(self) - Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheightdatum Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Get method: philamheightdatum(self) - Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamVermeille Get the latitude and Vermeille longitude in `radians [-PI*3/2..+PI*3/2]` (PhiLam2Tuple`(phi, lam)`). Get method: philamVermeille(self) - Get the latitude and Vermeille longitude in `radians [-PI*3/2..+PI*3/2]` (PhiLam2Tuple`(phi, lam)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property `lamVermeille`.

### phiVermeille Get the latitude in `radians` (`float`). Get method: phi(self) - Get the latitude in `radians` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz Get the geocentric `(x, y, z)` coordinates (Vector3Tuple`(x, y, z)`). Get method: xyz(self) - Get the geocentric `(x, y, z)` coordinates (Vector3Tuple`(x, y, z)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyzh Get the geocentric `(x, y, z)` coordinates and `height` (Vector4Tuple`(x, y, z, h)`) Get method: xyzh(self) - Get the geocentric `(x, y, z)` coordinates and `height` (Vector4Tuple`(x, y, z, h)`) Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.